import * as _nuxt_schema from '@nuxt/schema';

interface ModuleOptions {
    /**
     * Whether page views shall be tracked when the URL hash changes
     *
     * @remarks
     * Enable this if your Nuxt app has the `hashMode` router option enabled
     *
     * @default false
     */
    hashMode?: boolean;
    /**
     * Whether events shall be tracked when running the site locally
     *
     * @default false
     */
    trackLocalhost?: boolean;
    /**
     * The domain to bind tracking event to
     *
     * @default window.location.hostname
     */
    domain?: string;
    /**
     * The API host where the events will be sent to
     *
     * @default 'https://plausible.io'
     */
    apiHost?: string;
    /**
     * Track the current page and all further pages automatically
     *
     * @remarks
     * Disable this if you want to manually manage pageview tracking
     *
     * @default true
     */
    autoPageviews?: boolean;
    /**
     * Track all outbound link clicks automatically
     *
     * @remarks
     * If enabled, a [MutationObserver](https://developer.mozilla.org/en-US/docs/Web/API/MutationObserver) automagically detects link nodes throughout the application and binds `click` events to them
     *
     * @default false
     */
    autoOutboundTracking?: boolean;
}
declare const _default: _nuxt_schema.NuxtModule<ModuleOptions>;

export { ModuleOptions, _default as default };
